You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by da...@apache.org on 2011/07/09 21:00:53 UTC

svn commit: r1144717 - /subversion/trunk/subversion/include/svn_error.h

Author: danielsh
Date: Sat Jul  9 19:00:52 2011
New Revision: 1144717

URL: http://svn.apache.org/viewvc?rev=1144717&view=rev
Log:
Fix issue #3949.  This patch causes lock_tests to pass on all RA layers and, if
backported, against 1.6 svnserve as well.  It doesn't change the semantics of
the test (whether to expect a warning with zero exit code or an error with
non-zero exit code; currently it expects the former).

I'm not sure whether SVN_ERR_IS_UNLOCK_ERROR() should get the same treatment,
as it doesn't presently look for SVN_ERR_FS_OUT_OF_DATE either.  It should
probably check for both of them?

* subversion/include/svn_error.h
  (SVN_ERR_IS_LOCK_ERROR): 
    Include SVN_ERR_FS_NOT_FOUND.
    Fix preprocessor whitespace continuation.

Modified:
    subversion/trunk/subversion/include/svn_error.h

Modified: subversion/trunk/subversion/include/svn_error.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_error.h?rev=1144717&r1=1144716&r2=1144717&view=diff
==============================================================================
--- subversion/trunk/subversion/include/svn_error.h (original)
+++ subversion/trunk/subversion/include/svn_error.h Sat Jul  9 19:00:52 2011
@@ -383,14 +383,15 @@ svn_error_t *svn_error_purge_tracing(svn
  * Return TRUE if @a err is an error specifically related to locking a
  * path in the repository, FALSE otherwise.
  *
  * SVN_ERR_FS_OUT_OF_DATE is in here because it's a non-fatal error
  * that can be thrown when attempting to lock an item.
  *
  * @since New in 1.2.
  */
 #define SVN_ERR_IS_LOCK_ERROR(err)                          \
   (err->apr_err == SVN_ERR_FS_PATH_ALREADY_LOCKED ||        \
-   err->apr_err == SVN_ERR_FS_OUT_OF_DATE)                  \
+   err->apr_err == SVN_ERR_FS_NOT_FOUND           ||        \
+   err->apr_err == SVN_ERR_FS_OUT_OF_DATE)
 
 /**
  * Return TRUE if @a err is an error specifically related to unlocking
@@ -383,14 +383,15 @@ svn_error_t *svn_error_purge_tracing(svn
  * path in the repository, FALSE otherwise.
  *
- * SVN_ERR_FS_OUT_OF_DATE is in here because it's a non-fatal error
- * that can be thrown when attempting to lock an item.
+ * SVN_ERR_FS_OUT_OF_DATE and SVN_ERR_FS_NOT_FOUND are in here because it's a
+ * non-fatal error that can be thrown when attempting to lock an item.
  *
  * @since New in 1.2.